from boxes import valid_box_drawing

def test(drawing, expected):
    if valid_box_drawing(drawing) == expected:
        print("Passed")
    else:
        print(f"Failed: Expected {expected} for:")
        for line in drawing:
            print(line)


test([], True)
test([""], True)
test([" "], True)
test(["", ""], True)
test([" ", " "], True)
test(
    [
        "┌──────┐",
        "│      │",
        "│      │",
        "│      │",
        "└──────┘"
    ],
    True
)
test(
    [
        "┌──────────────────────────────────────────┐           ",
        "│                                          │           ",
        "│                                          │           ",
        "│                                          │           ",
        "│                                          │           ",
        "│                                          │         ┌┐",
        "│                                          │         └┘",
        "│                                          │           ",
        "│                                          │           ",
        "│                                          │           ",
        "│                                          │           ",
        "│                                          │           ",
        "└──────────────────────────────────────────┘           "
    ],
    True
)
test(
    [
        "┌──────┐┌────┐",
        "│      ││    │",
        "└──────┘└────┘"
    ],
    True
)
test(
    [
        "┌────────┐        ┌────────┐",
        "│        │        │        │",
        "│        ├────────┤        │",
        "│        │        │        │",
        "└────────┘        └────────┘"
    ],
    True
)
test(
    [
        " ┌───────┐ ",
        " │       │ ",
        "┌┴┐     ┌┴┐",
        "└─┘     └─┘"
    ],
    True
)
test(
    [
        " ┌───────┐",
        " │      ┌┘",
        "┌┴┐    ┌┴┐",
        "└─┘    └─┘"
    ],
    True
)
test(
    [
        "┌────────┐ ",
        "│ ┌─┐    │ ",
        "│ └┬┘    │ ",
        "└──┘     │ ",
        "        ┌┴┐",
        "        └─┘"
    ],
    True
)
test(
    [
        "┌─┐",
        "└┬┘",
        "┌┴┐",
        "└─┘"
    ],
    True
)
test(
    [
        "┌┐┌┐",
        "│├┤│",
        "└┘└┘"
    ],
    True
)
test(
    [
        "┌─┐┌─┐",
        "│ ├┤ │",
        "└┬┘└┬┘",
        "┌┴┐┌┴┐",
        "│ ├┤ │",
        "└─┘└─┘"
    ],
    True
)
test(
    [
        "        ┌───────┐",
        "        │       │",
        "  ┌─────┤       │",
        "  │     └───────┘",
        "┌─┴──┐           ",
        "│    │           ",
        "│    │           ",
        "└────┘           "
    ],
    True
)
test(
    [
        "┌──────┐             ",
        "└┬──┬──┘    ┌───────┐",
        " │  │       │       │",
        " │  └───────┤       │",
        " └────┐     └───┬───┘",
        "    ┌─┴──┐     ┌┘    ",
        "    │    │    ┌┘     ",
        "    │    ├┐   └────┐ ",
        "    └────┘└────────┘ "
    ],
    True
)
test(
    [
        "┌──────┐    ",
        "│      │    ",
        "│      └───┐",
        "│          │",
        "└──────────┘"
    ],
    False
)
test(
    [
        "a",
    ],
    False
)
test(
    [
        "┌",
    ],
    False
)
test(
    [
        "┌──────┬────┐",
        "│      │    │",
        "└──────┴────┘"
    ],
    False
)
test(
    [
        "     ┌────┐",
        "┌────┼────┘",
        "└────┘     "
    ],
    False
)
test(
    [
        "┌──────────────────────────────────────────┐",
        "│                                          │",
        "│                                          │",
        "│       ┌┐        ┌┐     ┌───────┐         │",
        "│       ││┌┐      ││     │┌─────┐│         │",
        "│       ││└┘┌┐    ││     ││     ││         │",
        "│       ││  └┘┌┐  ││     ││     ││         │",
        "│       ││    └┘┌┐││     ││     ││         │",
        "│       ││      └┘││     ││     ││         │",
        "│       ││        ││     │└─────┘│         │",
        "│       └┘        └┘     └───────┘         │",
        "│                                          │",
        "└──────────────────────────────────────────┘"
    ],
    False
)
test(
    [
        "┌──────┐          ┌───────",
        "│      │          │      │",
        "│                 │      │",
        "└──────┘          └──────┘",
        "                          ",
        "         ┌──────┐         ",
        "         │      │         ",
        "         │      ┤         ",
        "         └──────┘         "
    ],
    False
)
test(
    [
        "┌──────┐",
        "│      │",
        "│       ",
        "└──────┘"
    ],
    False
)
test(
    [
        "          ",
        " ┌─────── ",
        " │      │ ",
        " │      │ ",
        " └──────┘ ",
        "          "
    ],
    False
)
test(
    [
        "┌──────┐",
        "│      │",
        "│      ┤",
        "└──────┘"
    ],
    False
)
test(
    [
        "    ┌──────────────────┐    ",
        "┌───┴────┐        ┌────┴───┐",
        "│        │        │        │",
        "│        ├────────┤        │",
        "│        │        │        │",
        "└────────┘        └────────┘"
    ],
    False
)
test(
    [
        "┌────────┐        ┌────────┐",
        "│        │        │        │",
        "│        ├────────┤        │",
        "│        │        │        │",
        "└────────┤        └────────┘",
        "         │                  ",
        "         ├────────┐         ",
        "         │        │         ",
        "         │        │         ",
        "         │        │         ",
        "         └────────┘         "
    ],
    False
)
test(
    [
        "┌────────┐        ┌────────┐",
        "│        │        │        │",
        "│        ├────────┤        │",
        "│        │        │        │",
        "└────────┤        ├────────┘",
        "         │        │         ",
        "         ├────────┤         ",
        "         │        │         ",
        "         │        │         ",
        "         │        │         ",
        "         └────────┘         "
    ],
    False
)
test(
    [
        "┌┐     ┌┐     ┌┐     ┌┐  ",
        "││     ││     ││     ││  ",
        "│├──┴──┤│     │├──┐  │├─┐",
        "││     ││     ││  │  ││ │",
        "└┘     └┘     └┘  │  └┘ │",
        "                  │     │",
        "┌┐     ┌┐     ┌┐  │  ┌┐ │",
        "││     ││     ││  │  ││ │",
        "│├─────││     │├──┼──┤│ │",
        "││     ││     ││  │  ││ │",
        "└┘     └┘     └┘  │  └┘ │",
        "                  └─────┘"
    ],
    False
)
test(
    [
        "┌┐     ┌┐",
        "││     ││",
        "│├──┴──┤│",
        "││     ││",
        "└┘     └┘"
    ],
    False
)
test(
    [
        "┌┐     ┌┐",
        "││     ││",
        "│├─────││",
        "││     ││",
        "└┘     └┘"
    ],
    False
)
test(
    [
        "┌┐     ┌┐  ",
        "││     ││  ",
        "│├──┐  │├─┐",
        "││  │  ││ │",
        "└┘  │  └┘ │",
        "    │     │",
        "┌┐  │  ┌┐ │",
        "││  │  ││ │",
        "│├──┼──┤│ │",
        "││  │  ││ │",
        "└┘  │  └┘ │",
        "    └─────┘"
    ],
    False
)
test(
    [
        "┌────────┐",
        "│        │",
        "│        │",
        "│       ┌┘",
        "└───────┘ "
    ],
    False
)
